{% extends "base.html" %}

{% block app_content %}
    <h1>Beep Boop... Cannot Compute</h1>
    <img src="https://robohash.org/{{funny_word}}.png">
    <p><a href="{{ url_for('index') }}">Back</a></p>
{% endblock %}